==> zio-aws-clouddirectory_3-5.17.130.5-sources.jar: zio/aws/clouddirectory/model/UpdateObjectAttributesResponse.scala <==
package zio.aws.clouddirectory.model
import zio.aws.clouddirectory.model.primitives.ObjectIdentifier
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class UpdateObjectAttributesResponse(
    objectIdentifier: Option[ObjectIdentifier] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.clouddirectory.model.UpdateObjectAttributesResponse = {
    import UpdateObjectAttributesResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.clouddirectory.model.UpdateObjectAttributesResponse
      .builder()
      .optionallyWith(
        objectIdentifier.map(value =>
          ObjectIdentifier.unwrap(value): java.lang.String
        )
      )(_.objectIdentifier)
      .build()
  }
  def asReadOnly
      : zio.aws.clouddirectory.model.UpdateObjectAttributesResponse.ReadOnly =
    zio.aws.clouddirectory.model.UpdateObjectAttributesResponse
      .wrap(buildAwsValue())
}
object UpdateObjectAttributesResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.clouddirectory.model.UpdateObjectAttributesResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.clouddirectory.model.UpdateObjectAttributesResponse =
      zio.aws.clouddirectory.model
        .UpdateObjectAttributesResponse(objectIdentifier.map(value => value))
    def objectIdentifier: Option[ObjectIdentifier]
    def getObjectIdentifier: ZIO[Any, AwsError, ObjectIdentifier] =
      AwsError.unwrapOptionField("objectIdentifier", objectIdentifier)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.clouddirectory.model.UpdateObjectAttributesResponse
  ) extends zio.aws.clouddirectory.model.UpdateObjectAttributesResponse.ReadOnly {
    override val objectIdentifier: Option[ObjectIdentifier] = scala
      .Option(impl.objectIdentifier())
      .map(value =>
        zio.aws.clouddirectory.model.primitives.ObjectIdentifier(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.clouddirectory.model.UpdateObjectAttributesResponse
  ): zio.aws.clouddirectory.model.UpdateObjectAttributesResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-clouddirectory_3-5.17.195.3-sources.jar: zio/aws/clouddirectory/model/UpdateObjectAttributesResponse.scala <==
package zio.aws.clouddirectory.model
import zio.aws.clouddirectory.model.primitives.ObjectIdentifier
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class UpdateObjectAttributesResponse(
    objectIdentifier: Optional[ObjectIdentifier] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.clouddirectory.model.UpdateObjectAttributesResponse = {
    import UpdateObjectAttributesResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.clouddirectory.model.UpdateObjectAttributesResponse
      .builder()
      .optionallyWith(
        objectIdentifier.map(value =>
          ObjectIdentifier.unwrap(value): java.lang.String
        )
      )(_.objectIdentifier)
      .build()
  }
  def asReadOnly
      : zio.aws.clouddirectory.model.UpdateObjectAttributesResponse.ReadOnly =
    zio.aws.clouddirectory.model.UpdateObjectAttributesResponse
      .wrap(buildAwsValue())
}
object UpdateObjectAttributesResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.clouddirectory.model.UpdateObjectAttributesResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.clouddirectory.model.UpdateObjectAttributesResponse =
      zio.aws.clouddirectory.model
        .UpdateObjectAttributesResponse(objectIdentifier.map(value => value))
    def objectIdentifier: Optional[ObjectIdentifier]
    def getObjectIdentifier: ZIO[Any, AwsError, ObjectIdentifier] =
      AwsError.unwrapOptionField("objectIdentifier", objectIdentifier)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.clouddirectory.model.UpdateObjectAttributesResponse
  ) extends zio.aws.clouddirectory.model.UpdateObjectAttributesResponse.ReadOnly {
    override val objectIdentifier: Optional[ObjectIdentifier] =
      zio.aws.core.internal
        .optionalFromNullable(impl.objectIdentifier())
        .map(value =>
          zio.aws.clouddirectory.model.primitives.ObjectIdentifier(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.clouddirectory.model.UpdateObjectAttributesResponse
  ): zio.aws.clouddirectory.model.UpdateObjectAttributesResponse.ReadOnly =
    new Wrapper(impl)
}
